@@ -9,8 +9,18 @@ funs2fun <- function(...) {
   n <- length(fs)
   function(x, ...) {
     results <- NULL
+    args <- list(...)
+    namesargs <- names(args)
     for (i in 1:n) {
-      tmp <- match.fun(fs[[i]])(x, ...)
+      func <- match.fun(fs[[i]])
+      forms <- formals(func)
+      namesforms <- names(forms)
+      if (all(namesforms != "...")) {
+        finalargs <- c(list(x = x), args[namesargs %in% namesforms])
+      } else {
+        finalargs <- c(list(x = x), args)
+      }
+      tmp <- do.call(func, finalargs)
       names(tmp) <- paste(fnames[i], names(tmp))
       results <- c(results, tmp)
     }
