@@ -7,11 +7,12 @@
 ##' @param cum cum
 ##' @param margin margin
 ##' @param useNA useNA
+##' @param propNA propNA
 ##' @param revert whether to regroup factors or numeric variables when crossing factor with numeric variables
 ##' @param method method
 ##' @author David Hajage
 ##' @keywords internal
-cross <- function(x, y = NULL, funs = c(mean, sd, quantile, n, na), ..., cum = FALSE, margin = 0:2, useNA = c("no", "ifany", "always"), revert = FALSE, method = c("pearson", "kendall", "spearman")) {
+cross <- function(x, y = NULL, funs = c(mean, sd, quantile, n, na), ..., cum = FALSE, margin = 0:2, useNA = c("no", "ifany", "always"), propNA = TRUE, revert = FALSE, method = c("pearson", "kendall", "spearman")) {
   if (!is.character(funs)) {
     funs <- as.character(as.list(substitute(funs)))
     funs <- funs[funs != "c" & funs != "list"]
@@ -27,21 +28,21 @@ cross <- function(x, y = NULL, funs = c(mean, sd, quantile, n, na), ..., cum = F
       results <- summarize.data.frame.by(y, x, funs = funs, ..., useNA = useNA, revert = revert)
     }
     if (all(!sapply(x, is.numeric)) & all(!sapply(y, is.numeric))) {
-      results <- tabular.data.frame(x, y, margin = margin, useNA = useNA)
+      results <- tabular.data.frame(x, y, margin = margin, useNA = useNA, propNA = propNA)
     }
     if (all(sapply(x, is.numeric)) & all(sapply(y, is.numeric))) {
       results <- correlation.data.frame(x, y, method = method)
     }
   } else if (is.null(y)) {
     if (all(!sapply(x, is.numeric))) {
-      results <- freq.data.frame(x, useNA = useNA, cum = cum)
+      results <- freq.data.frame(x, useNA = useNA, propNA = propNA, cum = cum)
     }
     if (all(sapply(x, is.numeric))) {
       results <- summarize.data.frame(x, funs = funs, ...)
     }
   } else if (is.null(x)) {
     if (all(!sapply(y, is.numeric))) {
-      results <- freq.data.frame(y, useNA = useNA, cum = cum)
+      results <- freq.data.frame(y, useNA = useNA, propNA = propNA, cum = cum)
     } 
     if (all(sapply(y, is.numeric))) {
       results <- summarize.data.frame(y, funs = funs, ...)
@@ -67,7 +68,7 @@ cross <- function(x, y = NULL, funs = c(mean, sd, quantile, n, na), ..., cum = F
 ##' @param method method
 ##' @author David Hajage
 ##' @keywords internal
-cross_list <- function(l, funs = c(mean, sd, quantile, n, na), ..., cum = FALSE, margin = 0:2, useNA = c("no", "ifany", "always"), revert = FALSE, method = c("pearson", "kendall", "spearman")) {
+cross_list <- function(l, funs = c(mean, sd, quantile, n, na), ..., cum = FALSE, margin = 0:2, useNA = c("no", "ifany", "always"), propNA = TRUE, revert = FALSE, method = c("pearson", "kendall", "spearman")) {
 
   if (!is.character(funs)) {
     funs <- as.character(as.list(substitute(funs)))
@@ -81,7 +82,7 @@ cross_list <- function(l, funs = c(mean, sd, quantile, n, na), ..., cum = FALSE,
     y <- NULL
   }
 
-  cross(x = x, y = y, funs = funs, ..., cum = cum, margin = margin, useNA = useNA, revert = revert, method = method)
+  cross(x = x, y = y, funs = funs, ..., cum = cum, margin = margin, useNA = useNA, propNA = propNA, revert = revert, method = method)
 }
 
 ##' Regroup factors with factors, and numerical variables with numerical variables
@@ -129,6 +130,7 @@ regroup <- function(vars, numdata) {
 ##' @param margin index, or vector of indices to generate proportion
 ##' in frequency   tables (0: cell, 1: row, 2: col).
 ##' @param useNA whether to include NA as a level (factor)
+##' @param propNA whether to include NA in proportion calculation
 ##' @param revert whether to regroup factors or numeric variables when crossing factor with numeric variables
 ##' @param method a character string indicating which correlation
 ##' coefficient is to be   used. One of \code{"pearson"},
@@ -180,7 +182,7 @@ regroup <- function(vars, numdata) {
 ##' 
 ##' options(width = parwidth)
 ##' @keywords univar
-remix <- function(formula = cbind(...) ~ ., data, funs = c(mean, sd, quantile, n, na), ..., cum = FALSE, margin = 0:2, useNA = c("no", "ifany", "always"), revert = FALSE, method = c("pearson", "kendall", "spearman")) {
+remix <- function(formula = cbind(...) ~ ., data, funs = c(mean, sd, quantile, n, na), ..., cum = FALSE, margin = 0:2, useNA = c("no", "ifany", "always"), propNA = TRUE, revert = FALSE, method = c("pearson", "kendall", "spearman")) {
   
   if (is.formula(formula))
     formula <- deparse(formula, 500)
@@ -210,7 +212,7 @@ remix <- function(formula = cbind(...) ~ ., data, funs = c(mean, sd, quantile, n
       y <- sub("(cbind\\()(.*)(\\))", "\\2", y)
       lapply(y, function(z) data[, strsplit(z, ",")[[1]], drop = FALSE])})
     
-    results <- llply(comb, cross_list, funs = funs, ..., cum = cum, margin = margin, useNA = useNA, revert = revert, method = method)
+    results <- llply(comb, cross_list, funs = funs, ..., cum = cum, margin = margin, useNA = useNA, propNA = propNA, revert = revert, method = method)
     names(results) <- apply(eg, 1, paste, collapse = " ~ ")
   }
   
@@ -232,7 +234,7 @@ remix <- function(formula = cbind(...) ~ ., data, funs = c(mean, sd, quantile, n
       lapply(y, function(z) p[, strsplit(z, ",")[[1]], drop = FALSE])})))
 
     results <- lapply(combby, function(x) lapply(x, function(comb) {
-      res <- llply(comb, cross_list, funs = funs, cum = cum, margin = margin, useNA = useNA, revert = revert, method = method)
+      res <- llply(comb, cross_list, funs = funs, cum = cum, margin = margin, useNA = useNA, propNA = propNA, revert = revert, method = method)
       names(res) <- apply(eg, 1, paste, collapse = " ~ ")
       res
     }))
